@@ -9,6 +9,10 @@ class LayerComps(Photoshop):
 
     def __init__(self, parent):
         super().__init__(parent=parent)
+        self._flag_as_method(
+            "add",
+            "removeAll",
+        )
 
     def __len__(self):
         return self.length
